@@ -33,14 +33,14 @@ package G;
 
 use strict;
 
-# import prelude extensions
+# import "prelude" extensions
 use SubOpt;
 use Rcmd;
 
 # import messenger
 use G::Messenger;
 
-# import skyline extensions
+# import "skyline" extensions
 require G::Skyline;
 require G::DynamicLoader;
 use G::Inspire;
@@ -49,7 +49,7 @@ use G::Inspire;
 use G::DB::SDB;
 use G::DB::GDBI;
 
-# import odyssey classes
+# import "odyssey" classes
 use G::Seq::AminoAcid;
 use G::Seq::Codon;
 use G::Seq::Consensus;
@@ -98,7 +98,7 @@ use G::SystemsBiology::BioLayout;
 use G::SystemsBiology::Interaction;
 use G::SystemsBiology::DotE;
 
-# import presage classes
+# import "presage" classes
 use G::System::BAS;
 use G::System::GEMS;
 use G::System::COMGA;
@@ -107,7 +107,7 @@ use G::System::CHI;
 use G::System::ReL8;
 use G::System::FuncD;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK @INC);
+use vars qw($VERSION @ISA @EXPORT);
 
 require Exporter;
 
@@ -191,13 +191,13 @@ __END__
 
 =head1 NAME
 
-G - G-language Genome Analysis Environment Version 2.x core module (Skyline)
+G - G-language Genome Analysis Environment core interface module
 
 =head1 SYNOPSIS
 
  use G;                          # Imports G-language GAE module 
    
- $gb = new G("ecoli.gbk");       # Creates G's instance at $gb 
+ $gb = new G("ecoli.gbk");       # Creates G's instance as $gb 
                                  # At the same time, read in ecoli.gbk. 
                                  # Read the annotation and sequence 
                                  # information 
@@ -205,8 +205,9 @@ G - G-language Genome Analysis Environment Version 2.x core module (Skyline)
    
  $gb->seq_info();                # Prints the basic sequence information.
 
- $find_ori_ter(\$gb->{SEQ});     # Gives sequence as a reference to
-                                 # odyssey functions
+ $find_ori_ter($gb);      # Give $gb as the first argument to 
+                                 # most of the analysis functions
+
 
 =head1 DESCRIPTION
 
@@ -245,10 +246,8 @@ G - G-language Genome Analysis Environment Version 2.x core module (Skyline)
 
          To analyze each FEATURE, write: 
 
-         $i = 1;  
-         while(defined(%{$gb->{FEATURE$i}})){  
-   
-                 $i ++;  
+         foreach my $feature ($gb->feature()){
+               print $gb->{$feature}->{type}, "\n";
          }  
 
          Each CDS is stored in a similar manner.
@@ -261,11 +260,9 @@ G - G-language Genome Analysis Environment Version 2.x core module (Skyline)
                                           where "CDS$i" = "FEATURE$n"
 
          In the same manner, to analyze all CDS, write:  
-   
-         $i = 1;  
-         while(defined(%{$gb->{CDS$i}})){  
-   
-                 $i ++;  
+ 
+         foreach my $cds ($gb->cds()){
+               print $gb->{$cds}->{gene}, "\n";
          }
 
  BASE COUNT  
@@ -524,7 +521,7 @@ G - G-language Genome Analysis Environment Version 2.x core module (Skyline)
 
 =head1 AUTHOR
 
-Kazuharu Gaou Arakawa, gaou@g-language.org
+Kazuharu Arakawa, gaou@g-language.org
 
 =head1 SEE ALSO
 
